@@ -125,7 +125,7 @@ _update_uefi_lockdown_ms_files() {
 _update_syslinux_iso_files() {
 	
 	rm -f "${_ARCHBOOT_ISO_EXT_DIR}/boot/syslinux"/*.{com,bin,c32} || true
-	cp -f "/usr/lib/syslinux"/*.{com,bin,c32} "${_ARCHBOOT_ISO_EXT_DIR}/boot/syslinux/"
+	cp -f "/usr/lib/syslinux"/bios/*.{com,bin,c32} "${_ARCHBOOT_ISO_EXT_DIR}/boot/syslinux/"
 	
 }
 
@@ -189,16 +189,6 @@ LINUX /boot/vmlinuz_x86_64
 APPEND gpt loglevel=7 rootdelay=10
 INITRD /boot/initramfs_x86_64.img
 
-LABEL arch64-lts
-TEXT HELP
-Boot the Arch Linux LTS (x86_64) archboot medium. 
-It allows you to install Arch Linux or perform system maintenance.
-ENDTEXT
-MENU LABEL Boot Arch Linux LTS (x86_64)
-LINUX /boot/vmlinuz_x86_64_lts
-APPEND gpt loglevel=7 rootdelay=10
-INITRD /boot/initramfs_x86_64.img
-
 EOF
 	fi
 	
@@ -215,16 +205,6 @@ LINUX /boot/vmlinuz_i686
 APPEND gpt loglevel=7 rootdelay=10
 INITRD /boot/initramfs_i686.img
 
-LABEL arch32-lts
-TEXT HELP
-Boot the Arch Linux LTS (i686) archboot medium. 
-It allows you to install Arch Linux or perform system maintenance.
-ENDTEXT
-MENU LABEL Boot Arch Linux LTS (i686)
-LINUX /boot/vmlinuz_i686_lts
-APPEND gpt loglevel=7 rootdelay=10
-INITRD /boot/initramfs_i686.img
-
 EOF
 	fi
 	
@@ -342,14 +322,9 @@ GUMEOF
 title    Arch Linux ${_UEFI_ARCH} Archboot
 linux    /boot/vmlinuz_${_UEFI_ARCH}
 initrd   /boot/initramfs_${_UEFI_ARCH}.img
-options  gpt loglevel=7 efivars.pstore_disable=1 efi_pstore.pstore_disable=1 efi_no_storage_paranoia add_efi_memmap
+options  gpt loglevel=7 efi_pstore.pstore_disable=1 efi_no_storage_paranoia add_efi_memmap
 GUMEOF
-	
-	cat << GUMEOF > "${_ARCHBOOT_ISO_EXT_DIR}/loader/entries/archboot-${_UEFI_ARCH}-lts-efilinux.conf"
-title    Arch Linux LTS ${_UEFI_ARCH} Archboot via EFILINUX
-efi      /EFI/efilinux/efilinux${_SPEC_UEFI_ARCH}.efi
-GUMEOF
-	
+		
 	cat << GUMEOF > "${_ARCHBOOT_ISO_EXT_DIR}/loader/entries/uefi-shell-${_UEFI_ARCH}-v2.conf"
 title    UEFI Shell ${_UEFI_ARCH} v2
 efi      /EFI/tools/shell${_SPEC_UEFI_ARCH}_v2.efi
@@ -365,16 +340,6 @@ title    rEFInd ${_UEFI_ARCH}
 efi      /EFI/refind/refind${_SPEC_UEFI_ARCH}.efi
 GUMEOF
 	
-	rm -rf "${_ARCHBOOT_ISO_EXT_DIR}/EFI/efilinux/" || true
-	mkdir -p "${_ARCHBOOT_ISO_EXT_DIR}/EFI/efilinux"
-	cp -f "/usr/lib/efilinux/efilinux${_SPEC_UEFI_ARCH}.efi" "${_ARCHBOOT_ISO_EXT_DIR}/EFI/efilinux/efilinux${_SPEC_UEFI_ARCH}.efi"
-	echo
-	
-	cat << EOF > "${_ARCHBOOT_ISO_EXT_DIR}/EFI/efilinux/efilinux.cfg"
--f \\boot\\vmlinuz_${_UEFI_ARCH}_lts gpt loglevel=7 efivars.pstore_disable=1 efi_pstore.pstore_disable=1 efi_no_storage_paranoia add_efi_memmap initrd=\\boot\\initramfs_${_UEFI_ARCH}.img
-EOF
-	echo
-	
 }
 
 _update_uefi_rEFInd_USB_files() {
@@ -422,14 +387,7 @@ menuentry "Arch Linux ${_UEFI_ARCH} Archboot" {
     icon /EFI/refind/icons/os_arch.icns
     loader /boot/vmlinuz_${_UEFI_ARCH}
     initrd /boot/initramfs_${_UEFI_ARCH}.img
-    options "gpt loglevel=7 efivars.pstore_disable=1 efi_pstore.pstore_disable=1 efi_no_storage_paranoia add_efi_memmap"
-    ostype Linux
-    graphics off
-}
-
-menuentry "Arch Linux LTS ${_UEFI_ARCH} Archboot via EFILINUX" {
-    icon /EFI/refind/icons/os_arch.icns
-    loader /EFI/efilinux/efilinux${_SPEC_UEFI_ARCH}.efi
+    options "gpt loglevel=7 efi_pstore.pstore_disable=1 efi_no_storage_paranoia add_efi_memmap"
     ostype Linux
     graphics off
 }
@@ -452,7 +410,6 @@ EOF
 
 _remove_i686_iso_files() {
 	
-	rm -f "${_ARCHBOOT_ISO_EXT_DIR}/boot/vmlinuz_i686_lts" || true
 	rm -f "${_ARCHBOOT_ISO_EXT_DIR}/boot/vmlinuz_i686" || true
 	rm -f "${_ARCHBOOT_ISO_EXT_DIR}/boot/initramfs_i686.img" || true
 	rm -f "${_ARCHBOOT_ISO_EXT_DIR}/packages/archboot_packages_i686.squashfs" || true
@@ -463,7 +420,6 @@ _remove_i686_iso_files() {
 _remove_x86_64_iso_files() {
 	rm -rf "${_ARCHBOOT_ISO_EXT_DIR}/EFI" || true
         rm -rf "${_ARCHBOOT_ISO_EXT_DIR}/loader" || true
-	rm -f "${_ARCHBOOT_ISO_EXT_DIR}/boot/vmlinuz_x86_64_lts" || true
 	rm -f "${_ARCHBOOT_ISO_EXT_DIR}/boot/vmlinuz_x86_64" || true
 	rm -f "${_ARCHBOOT_ISO_EXT_DIR}/boot/initramfs_x86_64.img" || true
 	rm -f "${_ARCHBOOT_ISO_EXT_DIR}/packages/archboot_packages_x86_64.squashfs" || true
@@ -531,10 +487,10 @@ _download_pkgs() {
 }
 
 _update_cd_uefi() {
-        MOUNT_FSIMG=$(mktemp -d)
+	MOUNT_FSIMG=$(mktemp -d)
 
 	## get size of boot x86_64 files
-	BOOTSIZE=$(du -bc ${_ARCHBOOT_ISO_EXT_DIR}/{EFI,loader,boot/*x86_64*} | grep total | cut -f1)
+	BOOTSIZE=$(du -bc ${_ARCHBOOT_ISO_EXT_DIR}/{EFI,loader,boot/vmlinuz_x86_64,boot/initramfs_x86_64.img} | grep total | cut -f1)
 	IMGSZ=$(( (${BOOTSIZE}*102)/100/1024 + 1)) # image size in sectors
 
 	## Create cdefiboot.img
@@ -548,8 +504,8 @@ _update_cd_uefi() {
 
 	## Copy UEFI files fo cdefiboot.img
 	mkdir "${MOUNT_FSIMG}"/boot
-	cp -r "${_ARCHBOOT_ISO_EXT_DIR}"/{EFI,loader} "${MOUNT_FSIMG}"
-	cp "${_ARCHBOOT_ISO_EXT_DIR}"/boot/*x86_64* "${MOUNT_FSIMG}"/boot
+	cp -r "${_ARCHBOOT_ISO_EXT_DIR}"/{EFI,loader} "${MOUNT_FSIMG}"/
+	cp "${_ARCHBOOT_ISO_EXT_DIR}"/boot/vmlinuz_x86_64 "${_ARCHBOOT_ISO_EXT_DIR}"/boot/initramfs_x86_64.img "${MOUNT_FSIMG}"/boot/
 
 	## Unmount cdefiboot.img
 	umount "${LOOPDEV}"
@@ -618,7 +574,7 @@ xorriso -as mkisofs \
 	-eltorito-boot boot/syslinux/isolinux.bin \
 	-eltorito-catalog boot/syslinux/boot.cat \
 	-no-emul-boot -boot-load-size 4 -boot-info-table \
-	-isohybrid-mbr /usr/lib/syslinux/isohdpfx.bin \
+	-isohybrid-mbr /usr/lib/syslinux/bios/isohdpfx.bin \
 	${_CD_UEFI_PARAMETERS} \
 	-output "${_ARCHBOOT_ISO_UPDATED_PATH}" "${_ARCHBOOT_ISO_EXT_DIR}/" &> "/tmp/archboot_update_xorriso.log"
 echo
